@@ -1,5 +1,5 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el 4532 2007-05-04 01:13:44Z tv.raman.tv $
+;;; $Id: emacspeak-pronounce.el 5469 2008-02-20 00:55:48Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
+;;; $Date: 2008-02-19 16:55:48 -0800 (Tue, 19 Feb 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
@@ -108,15 +108,18 @@ This adds pronunciation pair
 STRING.PRONUNCIATION to the   dictionary.
 Argument KEY specifies a dictionary key e.g. directory, mode etc."
   (declare (special emacspeak-pronounce-dictionaries ))
-  (let ((dict  (emacspeak-pronounce-get-dictionary key)))
+  (let* ((dict  (emacspeak-pronounce-get-dictionary key))
+	 (entry (and dict (assoc string dict))))
     (cond
-     (dict
-      (setf dict
-            (cons (cons string pronunciation) dict))
+     ((and dict entry)
+      (setcdr entry pronunciation))
+     (dict 
+      (setf dict (cons (cons string pronunciation) dict))
       (emacspeak-pronounce-set-dictionary key dict ))
-     (t (emacspeak-pronounce-set-dictionary key
-                                            (list (cons string
-                                                        pronunciation)))))))
+     (t
+      (emacspeak-pronounce-set-dictionary key
+					  (list (cons string pronunciation)))))))
+
 (defun emacspeak-pronounce-remove-buffer-local-dictionary-entry (string)
   "Remove pronunciation entry."
   (when (and (boundp 'emacspeak-pronounce-pronunciation-table)
@@ -545,11 +548,11 @@ Activates pronunciation dictionaries if not already active."
     (":-I" .  " shrug ")
     (":->" . " sarcastic smile ")
     (">:->" . " devillish smile ")
-    (">;->" . " lews smile ")
+    (">;->" . " lewd smile ")
     (";-)" . " wink "))
   "Pronunciation dictionary used in all instant messenger and IRC chat
 modes.
-See http://oz.uc.edu/~solkode/smileys.html for a full list."
+See http://www.charm.net/~kmarsh/smiley.html. "
   :link '(url-link :tag "Smileys Dictionary "
                    "http://oz.uc.edu/~solkode/smileys.html")
   :type '(repeat
@@ -650,15 +653,14 @@ pronunciation dictionary for the specified key."
 
 (defun emacspeak-pronounce-edit-generate-callback (field-name)
   "Generate a callback for use in the pronunciation editor widget."
-  (`
-   (lambda (widget &rest ignore)
+  `(lambda (widget &rest ignore)
      (declare (special emacspeak-pronounce-dictionaries))
      (let ((value (widget-value widget)))
        (setf
         (gethash 
-         (quote (, field-name))
+         (quote ,field-name)
          emacspeak-pronounce-dictionaries)
-        value)))))
+        value))))
 
 ;;;###autoload
 (defun emacspeak-pronounce-edit-pronunciations (key)
