@@ -58,9 +58,11 @@
 
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
-(require 'calendar)
+(eval-when-compile
+  (require 'calendar))
 (require 'g-utils)
 (require 'g-auth)
+(require 'g-app)
 (require 'browse-url)
 
 ;;}}}
@@ -70,6 +72,17 @@
   "Google Calendar"
   :group 'g)
 
+;;;###autoload
+(defcustom gcal-default-user-email nil
+  "Default user id for Calendar."
+  :type '(choice
+          (const :tag "none" nil)
+          (string :tag "username@gmail.com" ""))
+  :group 'gcal)
+
+  
+
+;;;###autoload
 (defcustom gcal-user-email nil
   "Mail address that identifies calendar user."
   :type '(choice
@@ -113,19 +126,18 @@
   (declare (special gcal-auth-handle))
   (g-authenticate gcal-auth-handle))
 
+;;}}}
+;;{{{ Event Template:
+
 (defvar gcal-quickadd-template
   "<atom:entry xmlns:atom='http://www.w3.org/2005/Atom'>
   <atom:category scheme='http://schemas.google.com/g/2005#kind'
 term='http://schemas.google.com/g/2005#event'></atom:category>
   <atom:content type='text'>%s</atom:content>
-  <gCal:quickadd xmlns:gCal='http://schemas.google.com/gCal/2005'
-value='true'></gCal:quickadd>
+  <gCal:quickadd xmlns:gCal='http://schemas.google.com/gCal/2005'value='true'></gCal:quickadd>
 </atom:entry>"
   "Template for quickadd events.")
 
-;;}}}
-;;{{{ Event Template:
-
 ;;; template for calendar event.
 ;;; Format string takes following:
 ;; (title content
@@ -135,7 +147,9 @@ value='true'></gCal:quickadd>
 ;;        when-start when-end)
 
 (defvar gcal-event-template
-  "<entry xmlns='http://www.w3.org/2005/Atom' xmlns:gd='http://schemas.google.com/g/2005'>
+  "<entry xmlns='http://www.w3.org/2005/Atom' \
+xmlns:gd='http://schemas.google.com/g/2005' \
+xmlns:gCal='http://schemas.google.com/gCal/2005'>
 <category scheme='http://schemas.google.com/g/2005#kind' term='http://schemas.google.com/g/2005#event'>
 </category>
 <title type='text'>%s </title>
@@ -206,10 +220,10 @@ value='true'></gCal:quickadd>
 
 (defstruct gcal-attendee
   email
-  cn                                    ;firstname lastname
-  status                                ; needs-action, confirmed
-  role                       ; required participant, optional etc
-  resource-type                         ; individual, room
+  cn                              ;firstname lastname
+  status                          ; needs-action, confirmed
+  role                            ; required participant, optional etc
+  resource-type                   ; individual, room
   )
 
 ;;}}}
@@ -245,6 +259,7 @@ value='true'></gCal:quickadd>
   "Get status for event."
   (declare (special gcal-event-status-alist))
   (gcal-event-status-value 'confirmed))
+
 (defcustom gcal-calendar-view
   (expand-file-name "gcal-view.xsl" g-directory)
   "XSL transform used to view event feeds."
@@ -356,7 +371,7 @@ Default date is assumed to be today, or  the date selected when
       (push participant who))
     who))
 
-;;;###autoload
+
 (defun gcal-read-event (title content
                               where
                               start end
@@ -390,12 +405,23 @@ Default date is assumed to be today, or  the date selected when
 ;;{{{ Events:
 
 (defvar gcal-default-feed-url
-  "'http://www.google.com/calendar/feeds/default/private/full'"
+  "https://www.google.com/calendar/feeds/default/private/full"
   "URL for default calendar feed for currently authenticated
 user.")
 
+(defvar gcal-default-my-calendars-url
+  "https://www.google.com/calendar/feeds/default/owncalendars/full"
+  "URL for default calendar feed for currently authenticated
+user.")
+
+
+(defvar gcal-feed-url-template
+  "https://www.google.com/calendar/feeds/%s/%s/%s/?orderby=starttime"
+  "URL for  calendar feed using authentication.
+Parameterized by calendar name, private/public, and projecttion")
+
 (defvar gcal-private-feed-url
-  "'http://www.google.com/calendar/feeds/%s/private/full'"
+  "'https://www.google.com/calendar/feeds/%s/private/full'"
   "URL for private calendar feed using authentication.")
 
 (defsubst gcal-private-feed-url ()
@@ -405,47 +431,37 @@ user.")
   (format gcal-private-feed-url
           (g-url-encode (g-auth-email gcal-auth-handle))))
 
+(defsubst gcal-feed-url (resource privacy projection)
+  "Return  feed for specified resource..
+`privacy' specifies public/private.
+`projection' specifies desired projection, e.g. full vs free-busy."
+  (declare (special gcal-feed-url-template))
+  (format gcal-feed-url-template
+          (g-url-encode resource)
+          privacy projection))
+
 (defsubst gcal-post-event (event location)
   "Post event via HTTPS to location and return resulting HTTP headers."
-  (declare (special g-cookie-options gcal-auth-handle
-                    g-curl-program g-curl-common-options))
+  (declare (special  gcal-auth-handle
+                     g-app-auth-handle g-app-this-url))
   (g-using-scratch
+   (g-app-mode)
    (insert (gcal-event-as-xml event))
-   (let ((cl (format "-H Content-length:%s" (buffer-size)))
-         (status nil))
-     (shell-command-on-region
-      (point-min) (point-max)
-      (format
-       "%s %s %s %s %s -i -X POST --data-binary @- %s 2>/dev/null"
-       g-curl-program g-curl-common-options cl
-       (g-authorization gcal-auth-handle)
-       g-cookie-options
-       location)
-      (current-buffer) 'replace)
-     (list (g-http-headers (point-min) (point-max))
-           (g-http-body (point-min) (point-max))))))
+   (setq g-app-auth-handle gcal-auth-handle
+         g-app-this-url location)
+   (g-app-post-entry)))
 
 (defsubst gcal-post-quickadd (event-desc location)
   "Post quick event  via HTTPS to location and return resulting HTTP headers."
-  (declare (special g-cookie-options gcal-auth-handle
-                    gcal-quickadd-template
-                    g-curl-program g-curl-common-options))
+  (declare (special  gcal-auth-handle
+                     g-app-auth-handle g-app-this-url gcal-quickadd-template))
   (g-using-scratch
+   (g-app-mode)
    (insert
     (format gcal-quickadd-template event-desc))
-   (let ((cl (format "-H Content-length:%s" (buffer-size)))
-         (status nil))
-     (shell-command-on-region
-      (point-min) (point-max)
-      (format
-       "%s %s %s %s %s -i -X POST --data-binary @- %s 2>/dev/null"
-       g-curl-program g-curl-common-options cl
-       (g-authorization gcal-auth-handle)
-       g-cookie-options
-       location)
-      (current-buffer) 'replace)
-     (list (g-http-headers (point-min) (point-max))
-           (g-http-body (point-min) (point-max))))))
+   (setq g-app-auth-handle gcal-auth-handle
+         g-app-this-url location)
+   (g-app-post-entry)))
 
 (defun gcal-event-as-diary-entry (event)
   "Return an event string suitable for Emacs calendar's diary
@@ -477,21 +493,28 @@ file."
         (headers nil)
         (body nil)
         (response nil)
-        (location nil))
-    (setq response
-          (gcal-post-event event (gcal-private-feed-url)))
-    (setq headers (first response)
-          body (second response))
-    (setq status (g-http-header "Status" headers))
-    (when (string= "302" status)
-      (setq location (g-http-header "Location" headers))
-      (unless location
-        (error "Could not find redirect."))
-      (setq response  (gcal-post-event event location)))
-    (setq headers (first response)
-          body (second response))
-    (when  (string-equal "201" (g-http-header "Status" headers))
-      (and (> 0(length body))
+        (location (format gcal-private-feed-url
+                          (g-auth-email gcal-auth-handle))))
+    (while (or  (null  status)
+                (string= "302" status))
+      (message "posting.")
+      (setq response
+            (gcal-post-event event 
+                             (or location gcal-private-feed-url)))
+      (setq headers (first response)
+            body (second response))
+      (setq status (g-http-header "Status" headers)
+            location (g-http-header "Location" headers))
+      (message "Status: %s Location: %s"
+               status location)
+      (when (and status
+                 (string= "302" status))
+        (unless location
+          (error "Could not find redirect."))
+        (message "Following redirect to %s" location)))
+    (cond
+     ((string-equal "201" (g-http-header "Status" headers))
+      (and (> (length body)0)
            (g-display-xml-string body
                                  gcal-calendar-view))
       (message "Event added as %s" (g-http-header "Location"
@@ -501,9 +524,9 @@ file."
          (gcal-event-as-diary-entry event))
         (save-excursion
           (set-buffer (find-file-noselect diary-file))
-          (save-buffer))))))
-
-
+          (save-buffer))))
+     (t (error "Got %s"
+               (g-http-header "Status" headers))))))
 
 ;;;###autoload
 (defun gcal-quickadd-event (event-desc)
@@ -545,18 +568,7 @@ Specify the event in plain English."
                           (browse-url-url-at-point))))
   (declare (special gcal-auth-handle))
   (g-auth-ensure-token gcal-auth-handle)
-  (let ((headers nil)
-        (body nil)
-        (response nil))
-    (g-using-scratch
-     (shell-command
-      (format
-       "%s %s %s %s -i -X DELETE %s 2>/dev/null"
-       g-curl-program g-curl-common-options
-       (g-authorization gcal-auth-handle)
-       g-cookie-options
-       event-uri)
-      (current-buffer) 'replace))))
+  (g-app-delete-entry gcal-auth-handle event-uri))
 
 (defcustom gcal-event-accept
   (expand-file-name "gevent-accept.xsl" g-directory)
@@ -570,13 +582,14 @@ Specify the event in plain English."
     (read-from-minibuffer "Event URL: "
                           (browse-url-url-at-point))))
   (declare (special gcal-auth-handle g-cookie-options
+                    g-curl-program g-curl-common-options g-curl-atom-header
                     gcal-event-accept))
   (g-auth-ensure-token gcal-auth-handle)
   (g-using-scratch
    (shell-command
     (format
-     "%s %s %s %s  -X GET %s 2>/dev/null"
-     g-curl-program g-curl-common-options
+     "%s %s %s %s %s  -X GET %s 2>/dev/null"
+     g-curl-program g-curl-common-options g-curl-atom-header
      (g-authorization gcal-auth-handle)
      g-cookie-options
      event-uri)
@@ -589,54 +602,12 @@ Specify the event in plain English."
      (g-auth-email gcal-auth-handle)
      gcal-event-accept )
     (current-buffer) 'replace)
-   (let ((cl (format "-H Content-length:%s" (buffer-size))))
-     (shell-command-on-region
-      (point-min) (point-max)
-      (format
-       "%s %s %s %s %s -i -X PUT --data-binary @- %s 2>/dev/null"
-       g-curl-program g-curl-common-options cl
-       (g-authorization gcal-auth-handle)
-       g-cookie-options
-       event-uri)
-      (current-buffer) 'replace))))
+   (g-app-mode)
+   (setq g-app-auth-handle gcal-auth-handle
+         g-app-this-url event-uri)
+   (g-app-put-entry)))
 
 ;;;###autoload
-(defun gcal-show-calendar (&optional calendar start-min start-max)
-  "Show calendar for currently authenticated user."
-  (interactive
-   (list
-    (if current-prefix-arg
-        (read-from-minibuffer "Calendar URI:"
-                              (gcal-private-feed-url))
-      (gcal-private-feed-url))
-    (if current-prefix-arg
-        (read-from-minibuffer "Start:"
-                              (format-time-string
-                               gcal-event-time-format
-                               (current-time))))
-    (if current-prefix-arg
-        (read-from-minibuffer "End:"
-                              (format-time-string
-                               gcal-event-time-format (current-time))))))
-  (declare (special gcal-auth-handle
-                    gcal-calendar-view))
-  (g-auth-ensure-token gcal-auth-handle)
-  (g-display-result
-   (format
-    "%s %s %s %s  '%s%s' 2>/dev/null"
-    g-curl-program g-curl-common-options
-    (g-authorization gcal-auth-handle)
-    g-cookie-options
-    (or calendar (gcal-private-feed-url))
-    (cond
-     ((and (null start-min)
-           (null start-max))
-      "?orderby=starttime")
-     (t
-      (format "?orderby=starttime&start-min=%s&start-max=%s"
-              (or start-min "")
-              (or start-max "")))))
-   gcal-calendar-view))
 
 (defcustom gcal-calendar-agenda-days 5
   "Number of days for which we show an agenda by default."
@@ -648,7 +619,6 @@ Specify the event in plain English."
   :type 'boolean
   :group 'gcal)
 
-
 (defun gcal-calendar-get-date (&optional date )
   "Get GCal date from a calendar date spec.
 Default is to use calendar date under point."
@@ -660,7 +630,15 @@ Default is to use calendar date under point."
           (first date)
           (list (third date)))))
 
-(defun gcal-calendar-agenda  (&optional calendar)
+(defconst gcal-privacy-choices
+  '("public" "private" )
+  "Choices for public or private.")
+
+(defconst gcal-projection-choices
+  '("free-busy" "full" "owner")
+  "Choices for project types.")
+
+(defun gcal-calendar-agenda  (&optional resource privacy projection)
   "Show agenda for currently authenticated user.
 With interactive prefix arg, prompts for calendar to show. This
 command is best invoked from within the emacs calendar. It uses
@@ -669,15 +647,24 @@ show the agenda. If no mark is set in the calendar, the agenda is
 shown for the next `gcal-calendar-agenda-days' days following the
 date under point."
   (interactive
-   (list
-    (if current-prefix-arg
-        (read-from-minibuffer "Calendar URI:"
-                              (gcal-private-feed-url))
-      (gcal-private-feed-url))))
+   (cond
+    (current-prefix-arg
+     (list
+      (read-from-minibuffer "Calendar For: "
+                            (g-auth-email gcal-auth-handle))
+      (completing-read  "Privacy: "
+                        gcal-privacy-choices)
+      (completing-read "Projection: "
+                       gcal-projection-choices)))
+    (t (list (g-auth-email  gcal-auth-handle)
+             "private" "full"))))
   (declare (special gcal-auth-handle
+                    gcal-privacy-choices gcal-projection-choices
                     gcal-calendar-view
                     calendar-mark-ring))
-  (let* ((start-min
+  (let* ((calendar
+          (gcal-feed-url resource  privacy projection))
+         (start-min
           (g-url-encode
            (gcal-calendar-get-date
             (when (eq major-mode 'calendar-mode)
@@ -705,16 +692,35 @@ date under point."
       g-curl-program g-curl-common-options
       (g-authorization gcal-auth-handle)
       g-cookie-options
-      (or calendar (gcal-private-feed-url))
+      calendar
       (cond
        ((and (null start-min)
              (null start-max))
-        "?orderby=starttime")
+        "")
        (t
-        (format "?orderby=starttime&start-min=%s&start-max=%s"
+        (format "&start-min=%s&start-max=%s"
                 (or start-min "")
                 (or start-max "")))))
-     gcal-calendar-view)))
+     gcal-calendar-view     )))
+
+;;;###autoload
+
+(defun gcal-view (resource)
+  "Retrieve and display resource after authenticating."
+  (interactive "sResource: ")
+  (declare (special gcal-auth-handle gcal-calendar-view
+                    g-cookie-options
+                    g-curl-program g-curl-common-options))
+  (g-auth-ensure-token gcal-auth-handle)
+  (g-display-result
+   (format
+    "%s %s %s %s '%s' %s"
+    g-curl-program g-curl-common-options
+    g-cookie-options
+    (g-authorization gcal-auth-handle)
+    resource
+    (g-curl-debug))
+   gcal-calendar-view))
 
 ;;;###autoload
 (defun gcal-show-event (url)
@@ -735,7 +741,7 @@ date under point."
 ;;}}}
 ;;{{{ Feed of feeds:
 (defvar gcal-feeds-template-url
-  "'http://www.google.com/calendar/feeds/%s'"
+  "'https://www.google.com/calendar/feeds/%s'"
   "URL template for feed of feeds from calendar.")
 (defsubst gcal-feeds-url (userid)
   "Return url for feed of feeds."
@@ -743,7 +749,23 @@ date under point."
   (format gcal-feeds-template-url userid))
 
 (defun gcal-calendars ()
-  "Retrieve and display feed of feeds after authenticating."
+  "Retrieve and display feed of feeds for specified user  after authenticating."
+  (interactive)
+  (declare (special gcal-auth-handle g-atom-view-xsl
+                    g-curl-program g-curl-common-options
+                    g-cookie-options))
+  (g-auth-ensure-token gcal-auth-handle)
+  (g-display-result
+   (format
+    "%s %s %s %s '%s' 2>/dev/null"
+    g-curl-program g-curl-common-options
+    g-cookie-options
+    (g-authorization gcal-auth-handle)
+    (gcal-feeds-url "default"))
+   g-atom-view-xsl))
+
+(defun gcal-my-calendars ()
+  "Retrieve and display feed of `owned' calendars after authenticating."
   (interactive)
   (declare (special gcal-auth-handle
                     g-atom-view-xsl
@@ -756,10 +778,13 @@ date under point."
     g-curl-program g-curl-common-options
     g-cookie-options
     (g-authorization gcal-auth-handle)
-    (gcal-feeds-url
-     (g-url-encode (g-auth-email gcal-auth-handle))))
+    (concat
+     (gcal-feeds-url "default")
+     "/owncalendars/full"))
    g-atom-view-xsl))
 
+
+
 ;;}}}
 ;;{{{ Interfacing with Emacs Calendar:
 ;;;###autoload
@@ -775,7 +800,6 @@ date under point."
         '(
           ("a" gcal-add-event)
           ("c" gcal-calendar-agenda)
-          ("s" gcal-show-calendar)
           )
         do
         (define-key gcal-calendar-prefix-map (first binding)
@@ -783,7 +807,7 @@ date under point."
 
 ;;}}}
 ;;{{{ Sign out:
-
+;;;###autoload
 (defun gcal-sign-out()
   "Resets client so you can start with a different userid."
   (interactive)
@@ -795,6 +819,18 @@ date under point."
         gcal-user-password nil)
   (setq gcal-auth-handle (make-gcal-auth)))
 
+;;;###autoload
+(defun gcal-sign-in()
+  "Sign in, useful when changing to a different user profile."
+  (interactive)
+  (declare (special gcal-auth-handle gcal-user-email
+                    gcal-default-user-email))
+  (setq gcal-user-email
+        (read-from-minibuffer "Calendar User: "
+                              gcal-default-user-email))
+  (setq gcal-auth-handle (make-gcal-auth))
+  (gcal-authenticate))
+
 ;;}}}
 (provide 'gcal)
 ;;{{{ end of file
