@@ -303,16 +303,26 @@ user."
   (concat greader-base-url
           "api/0/subscription/list?output=json")
   "URL for retrieving list of subscribed feeds.")
+
+(defvar greader-unread-count-url
+  (concat greader-base-url
+          "api/0/unread-count?all=true&output=json")
+  "URL for retrieving unread counts for subscribed  feeds.")
+
+(defvar greader-subscription-opml-url
+  (concat greader-base-url
+          "subscriptions/export")
+  "URL for retrieving list of subscribed feeds.")
+
 (defvar greader-tag-list-url
   (concat greader-base-url
           "api/0/tag/list?output=json")
   "URL for retrieving list of tags.")
 
-(defun greader-view-json-subscriptions (subscriptions)
+(defun greader-view-json-subscriptions (subscriptions counts)
   "View Greader Subscription list."
   (declare (special greader-atom-base))
   (g-using-scratch
-   (erase-buffer)
    (insert
     (format
      "<html><head>
@@ -324,15 +334,17 @@ user."
             (g-auth-username greader-auth-handle)))
    (loop for s across subscriptions
          do
-         (let ((id (g-json-get 'id s)))
+         (let* ((id (g-json-get 'id s))
+                    (count (greader-get-unread-count-by-id id counts)))
            (insert
             (format
-             "<li><a href=\"%s\">%s (%s)</a></li>\n"
+             "<li><a href=\"%s\">%s (%s: %s)</a></li>\n"
              (let ((url (substring id 5)))
                (cond
                 ((string-match "^http" url) url)
                 (t (concat greader-atom-base url))))
              (g-json-get 'title s)
+             count
              (cond
               ((string-match "rss" id) "R")
               ((string-match "atom" id) "A")
@@ -340,17 +352,77 @@ user."
    (insert "</ol></body></html>\n")
    (browse-url-of-region (point-min) (point-max))))
 
+(defun greader-view-json-results (query results)
+  "View Greader results list."
+  (declare (special greader-atom-base))
+  (let ((items (g-json-get 'items results)))
+    (g-using-scratch
+         (insert
+    (format
+     "<html><head>
+<title> Results Matching %s</title>
+</head>\n"
+     query))
+   (insert
+    (format "<body><h1>Results Matching  %s</h1>\n<ol>"
+            query))
+   (loop for item across items
+         do
+         (insert
+          (format "<h2><a href=\"%s\">%s</a></h2>\n"
+         (g-json-get 'title item)
+(g-json-get 'title item)))
+(insert
+ (format "<div>%s</div>\n"
+         (g-json-get 'content
+                     (g-json-get 'content item))))))))
+
+
+(defun greader-unread-count ()
+  "Retrieve unread counts for subscribed feeds."
+  (declare (special greader-auth-handle
+                    g-curl-program g-curl-common-options
+                    greader-unread-count-url))
+  (let ((counts
+         (g-json-get 'unreadcounts
+                     (g-json-get-result
+                      (format
+                       "%s %s --cookie SID='%s' '%s' 2>/dev/null"
+                       g-curl-program g-curl-common-options
+                       (g-cookie "SID" greader-auth-handle)
+                       greader-unread-count-url)))))
+    counts))
+
+(defsubst greader-get-unread-count-by-id (id counts)
+  "Given a Feed Id, get the unread count from the cache in counts."
+  (let ((c
+         (find-if
+          #'(lambda (a)
+              (equal (g-json-get 'id a) id))
+          counts)))
+    (g-json-get 'count  c)))
+
+(defsubst greader-get-timestamp-by-id (id counts)
+  "Given a Feed Id, get the timestamp from the cache in counts."
+  (let ((c
+         (find-if
+          #'(lambda (a)
+              (equal (g-json-get 'id a) id))
+          counts)))
+    (g-json-get 'newestItemTimestampUsec c)))
+
 ;;;###autoload
 (defun greader-feed-list (&optional sort)
   "Retrieve list of subscribed feeds.
-Optional interactive prefix arg `sort' sorts feeds based on newly
-arrived articles."
+Feeds are sorted by timestamp of newly arrived articles.
+Optional interactive prefix arg `sort' turns on sorting."
   (interactive "P")
   (declare (special greader-auth-handle
                     g-curl-program g-curl-common-options
                     greader-subscribed-feed-list-url))
   (g-auth-ensure-token greader-auth-handle)
-  (let ((subscriptions
+  (let ((counts (greader-unread-count))
+        (subscriptions
          (g-json-get 'subscriptions
                      (g-json-get-result
                       (format
@@ -359,12 +431,30 @@ arrived articles."
                        (g-cookie "SID" greader-auth-handle)
                        greader-subscribed-feed-list-url)))))
     (when sort
-      (setq subscriptions
-            (sort* subscriptions
-                   #'(lambda (a b)
-                       (< (string-to-number (g-json-get 'firstitemmsec b))
-                          (string-to-number (g-json-get 'firstitemmsec a)))))))
-    (greader-view-json-subscriptions subscriptions)))
+    (setq subscriptions
+          (sort* subscriptions
+                 #'(lambda (a b)
+                     (let ((a-id (g-json-get 'id a))
+                           (b-id (g-json-get 'id b)))
+                       (>
+                        (greader-get-unread-count-by-id a-id counts)
+                        (greader-get-unread-count-by-id b-id counts)))))))
+    (greader-view-json-subscriptions subscriptions counts)))
+
+;;;###autoload
+
+(defun greader-opml ()
+  "Retrieve OPML representation of our subscription list."
+  (interactive)
+  (declare (special greader-auth-handle greader-subscription-opml-url
+                    g-curl-program g-curl-common-options))
+  (g-auth-ensure-token greader-auth-handle)
+  (shell-command
+   (format
+    "%s %s --cookie SID='%s' %s 2>/dev/null"
+    g-curl-program g-curl-common-options
+    (g-cookie "SID" greader-auth-handle)
+    greader-subscription-opml-url)))
 
 (defun greader-view-json-tags (tags)
   "View Greader tag list."
@@ -443,6 +533,7 @@ arrived articles."
     (read-from-minibuffer "Feed URL: "
                           (funcall g-url-under-point))))
   (greader-update-subscription feed-url 'title))
+
 ;;;###autoload
 (defun greader-tag-feed (feed-url )
   "Tag  specified feed."
@@ -490,7 +581,7 @@ arrived articles."
                      ('add-tags "Add Tag:")
                      ('remove-tags "Remove Tag:")))
                 "")))
-     (setq cl (format "-H Content-length:%s" (buffer-size)))
+     (setq cl (format "-H Content-length:%s" (g-buffer-bytes)))
      (shell-command-on-region
       (point-min) (point-max)
       (format
@@ -506,6 +597,7 @@ arrived articles."
      (message "%s %s" action feed-url))
     (t (error "Error %s: %s"
               action (buffer-string))))))
+
 (defsubst greader-read-item-url (prompt)
   "Smart reader for fetching item urls."
   (let ((guess (and (fboundp g-url-under-point)
@@ -592,8 +684,64 @@ arrived articles."
       url)
      g-atom-view-xsl)))
 
+;;}}}
+;;{{{ Searching:
+
+(defvar greader-search-url
+  (concat greader-base-url
+          "api/0/search/items/ids?output=json&num=100&q=%s")
+  "URL template for GReader search.")
+
+(defvar greader-contents-rest-url
+  "http://www.google.com/reader/api/0/stream/items/contents"
+  "REST endpoint for getting content.")
+;;;###autoload
+(defun greader-search (query)
+  "GReader search."
+  (interactive "sQuery:")
+  (declare (special greader-auth-handle
+                    g-curl-program g-curl-common-options
+                    greader-contents-rest-url
+                    greader-search-url g-atom-view-xsl))
+  (g-auth-ensure-token greader-auth-handle)
+  (let ((results 
+         (g-json-get 'results
+                     (g-json-get-result
+                      (format
+                       "%s %s --cookie SID='%s' '%s' 2>/dev/null"
+                       g-curl-program g-curl-common-options
+                       (g-cookie "SID" greader-auth-handle)
+                       (format greader-search-url
+                               (g-url-encode query))))))
+        (docids nil))
+    (setq docids 
+          (loop for i across results
+                collect (cdr (assq 'id i))))
+    (g-using-scratch
+     (let ((cl  nil))
+       (insert 
+        (format "T=%s" (g-auth-token greader-auth-handle)))
+       (loop for i in docids 
+             do
+             (insert (format "&i=%s" i)))
+       (setq cl (format "-H Content-length:%s" (g-buffer-bytes)))
+       (shell-command-on-region
+        (point-min) (point-max)
+        (format
+         "%s %s --cookie SID='%s' %s -X POST --data-binary @- %s 2>/dev/null"
+         g-curl-program g-curl-common-options
+         (g-cookie "SID" greader-auth-handle)
+         cl                             ; content-length header
+         greader-contents-rest-url)
+        (current-buffer) 'replace))
+     (greader-view-json-results
+      query
+      (json-read-from-string
+       (buffer-string))))))
+
 ;;}}}
 ;;{{{ Sign out:
+;;;###autoload
 (defun greader-sign-out()
   "Resets client so you can start with a different userid."
   (interactive)
@@ -606,7 +754,18 @@ arrived articles."
     (setq greader-user-email nil
           greader-user-password nil)
     (setq greader-auth-handle (make-greader-auth)))
-   (t (message "You've not used Reader in this emacs session."))))
+   (t (message "You've not used Reader in this emacs
+session."))))
+
+;;;###autoload
+(defun greader-sign-in()
+  "Resets client so you can start with a different userid."
+  (interactive)
+  (declare (special greader-auth-handle greader-user-email ))
+  (setq greader-user-email
+        (read-from-minibuffer "User Email:"))
+  (setq greader-auth-handle (make-greader-auth))
+  (g-authenticate greader-auth-handle))
 
 ;;}}}
 
